@@ -202,6 +202,7 @@ class ErrorCodes(object):
         FileIsTooLarge = "84902"
         FileTypeIsInvalid = "84903"
         FileIsMalformedOrEncrypted = "84904"
+        FileIsTooLong = "84905"
 
     class Merchant(object):
         CountryCannotBeBlank = "83603"
@@ -519,6 +520,7 @@ class ErrorCodes(object):
         MerchantAccountDoesNotMatchIdealPaymentMerchantAccount = "915143"
         MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
+        MerchantAccountIdDoesNotMatchSubscription = "915180"
         MerchantAccountIdIsInvalid = "91513"
         MerchantAccountIsSusped = "91514" # Deprecated
         MerchantAccountIsSuspended = "91514"
@@ -619,6 +621,49 @@ class ErrorCodes(object):
                 DepartureDateIsInvalid = "93411"
                 LodgingCheckInDateIsInvalid = "93412"
                 LodgingCheckOutDateIsInvalid = "93413"
+            class TravelFlight(object):
+                EmptyData = "93414"
+                UnknownDataField = "93415"
+                CustomerCodeIsTooLong = "93416"
+                FareAmountCannotBeNegative = "93417"
+                FareAmountFormatIsInvalid = "93418"
+                FareAmountIsTooLarge = "93419"
+                FeeAmountCannotBeNegative = "93420"
+                FeeAmountFormatIsInvalid = "93421"
+                FeeAmountIsTooLarge = "93422"
+                IssuedDateFormatIsInvalid = "93423"
+                IssuingCarrierCodeIsTooLong = "93424"
+                PassengerMiddleInitialIsTooLong = "93425"
+                RestrictedTicketIsRequired = "93426"
+                TaxAmountCannotBeNegative = "93427"
+                TaxAmountFormatIsInvalid = "93428"
+                TaxAmountIsTooLarge = "93429"
+                TicketNumberIsTooLong = "93430"
+                LegsExpected = "93431"
+                TooManyLegs = "93432"
+
+            class Leg(object):
+                class TravelFlight(object):
+                    ArrivalAirportCodeIsTooLong = "96301"
+                    ArrivalTimeFormatIsInvalid = "96302"
+                    CarrierCodeIsTooLong = "96303"
+                    ConjunctionTicketIsTooLong = "96304"
+                    CouponNumberIsTooLong = "96305"
+                    DepartureAirportCodeIsTooLong = "96306"
+                    DepartureTimeFormatIsInvalid = "96307"
+                    ExchangeTicketIsTooLong = "96308"
+                    FareAmountCannotBeNegative = "96309"
+                    FareAmountFormatIsInvalid = "96310"
+                    FareAmountIsTooLarge = "96311"
+                    FareBasisCodeIsTooLong = "96312"
+                    FeeAmountCannotBeNegative = "96313"
+                    FeeAmountFormatIsInvalid = "96314"
+                    FeeAmountIsTooLarge = "96315"
+                    ServiceClassIsTooLong = "96316"
+                    TaxAmountCannotBeNegative = "96317"
+                    TaxAmountFormatIsInvalid = "96318"
+                    TaxAmountIsTooLarge = "96319"
+                    TicketNumberIsTooLong = "96320"
 
         class LineItem(object):
             CommodityCodeIsTooLong = "95801"
